import 'package:flutter/material.dart';

class RefreshableListView extends StatefulWidget {
  final refreshKey = GlobalKey();
  final IndexedWidgetBuilder itemBuilder;
  final int itemCount;
  final Function refreshCallback;
  final double itemExtend;
  final Color color;
  final Color backgroundColor;
  final EdgeInsetsGeometry itemPadding;

  RefreshableListView(
      {@required this.itemBuilder,
      @required this.itemCount,
      @required this.refreshCallback,
      this.color,
      this.backgroundColor,
      this.itemPadding,
      this.itemExtend = 100.0});

  @override
  State<StatefulWidget> createState() {
    return RefreshableListViewState();
  }
}

class RefreshableListViewState extends State<RefreshableListView> {
  @override
  void initState() {
    widget.refreshCallback();
    super.initState();
  }

  Future<void> refresh() async {
    await Future.delayed(Duration(seconds: 1));

    setState(() {
      widget.refreshCallback();
    });

    return null;
  }

  @override
  Widget build(BuildContext context) {
    return RefreshIndicator(
      key: widget.refreshKey,
      child: ListView.builder(
        itemBuilder: widget.itemBuilder,
        itemCount: widget.itemCount,
        itemExtent: widget.itemExtend,
        padding: widget.itemPadding,
      ),
      onRefresh: refresh,
      color: widget.color,
      backgroundColor: widget.backgroundColor,
    );
  }
}
